Package 'valdrViz'

Title: Visualise and Report 'VALD ForceDecks' Test Results
Description: Provides a 'shiny' dashboard and plotting utilities to explore and report 'VALD ForceDecks' testing data. Includes interactive modules for metric exploration, radar charts, longitudinal comparisons, quadrant plots, and athlete reports.
Authors: Kieran Harrison [aut, cre], VALD Support [ctb], VALD [cph] (Copyright holder)
Maintainer: Kieran Harrison <[email protected]>
License: MIT + file LICENSE
Version: 1.0.1
Built: 2026-05-20 08:50:13 UTC
Source: https://github.com/cran/valdrViz

Help Index


Forward pipe operator

Description

See 'magrittr::%>%' for details.

Usage

lhs %>% rhs

Arguments

lhs, rhs

Objects to pipe.

Value

The result of applying the right-hand side expression to the left-hand side value.


Run the VALD ForceDecks Performance Dashboard

Description

Launches an interactive 'shiny' application for exploring your ForceDecks data.

Usage

forcedecks_performance_dashboard(
  data = NULL,
  launch.browser = TRUE,
  tabs = c("metric_explorer", "radar", "longit", "quadrant", "player_report")
)

Arguments

data

Optional ForceDecks data.frame. If NULL, the app will prompt for CSV files.

launch.browser

Logical. Launch app in a browser window.

tabs

Character vector of tabs to show.

Value

No return value, called for side effects (launches the 'shiny' application).

Examples

if (interactive()) {
    forcedecks_performance_dashboard()
}