| Title: | Visualise and Report 'VALD ForceDecks' Test Results |
|---|---|
| Description: | Provides a 'shiny' dashboard and plotting utilities to explore and report 'VALD ForceDecks' testing data. Includes interactive modules for metric exploration, radar charts, longitudinal comparisons, quadrant plots, and athlete reports. |
| Authors: | Kieran Harrison [aut, cre], VALD Support [ctb], VALD [cph] (Copyright holder) |
| Maintainer: | Kieran Harrison <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0.1 |
| Built: | 2026-05-20 08:50:13 UTC |
| Source: | https://github.com/cran/valdrViz |
See 'magrittr::%>%' for details.
lhs %>% rhslhs %>% rhs
lhs, rhs
|
Objects to pipe. |
The result of applying the right-hand side expression to the left-hand side value.
Launches an interactive 'shiny' application for exploring your ForceDecks data.
forcedecks_performance_dashboard( data = NULL, launch.browser = TRUE, tabs = c("metric_explorer", "radar", "longit", "quadrant", "player_report") )forcedecks_performance_dashboard( data = NULL, launch.browser = TRUE, tabs = c("metric_explorer", "radar", "longit", "quadrant", "player_report") )
data |
Optional ForceDecks data.frame. If NULL, the app will prompt for CSV files. |
launch.browser |
Logical. Launch app in a browser window. |
tabs |
Character vector of tabs to show. |
No return value, called for side effects (launches the 'shiny' application).
if (interactive()) { forcedecks_performance_dashboard() }if (interactive()) { forcedecks_performance_dashboard() }